==> cognito-1.60.0-sources.jar: software/amazon/awscdk/services/cognito/CfnUserPoolDomainProps.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Properties for defining a `AWS::Cognito::UserPoolDomain`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooldomain.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.697Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.CfnUserPoolDomainProps")
@software.amazon.jsii.Jsii.Proxy(CfnUserPoolDomainProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUserPoolDomainProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Cognito::UserPoolDomain.Domain`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooldomain.html#cfn-cognito-userpooldomain-domain
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDomain();

    /**
     * `AWS::Cognito::UserPoolDomain.UserPoolId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooldomain.html#cfn-cognito-userpooldomain-userpoolid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserPoolId();

    /**
     * `AWS::Cognito::UserPoolDomain.CustomDomainConfig`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooldomain.html#cfn-cognito-userpooldomain-customdomainconfig
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCustomDomainConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnUserPoolDomainProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUserPoolDomainProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUserPoolDomainProps> {
        private java.lang.String domain;
        private java.lang.String userPoolId;
        private java.lang.Object customDomainConfig;

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getDomain}
         * @param domain `AWS::Cognito::UserPoolDomain.Domain`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domain(java.lang.String domain) {
            this.domain = domain;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getUserPoolId}
         * @param userPoolId `AWS::Cognito::UserPoolDomain.UserPoolId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userPoolId(java.lang.String userPoolId) {
            this.userPoolId = userPoolId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getCustomDomainConfig}
         * @param customDomainConfig `AWS::Cognito::UserPoolDomain.CustomDomainConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customDomainConfig(software.amazon.awscdk.core.IResolvable customDomainConfig) {
            this.customDomainConfig = customDomainConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getCustomDomainConfig}
         * @param customDomainConfig `AWS::Cognito::UserPoolDomain.CustomDomainConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customDomainConfig(software.amazon.awscdk.services.cognito.CfnUserPoolDomain.CustomDomainConfigTypeProperty customDomainConfig) {
            this.customDomainConfig = customDomainConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUserPoolDomainProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUserPoolDomainProps build() {
            return new Jsii$Proxy(domain, userPoolId, customDomainConfig);
        }
    }

    /**
     * An implementation for {@link CfnUserPoolDomainProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUserPoolDomainProps {
        private final java.lang.String domain;
        private final java.lang.String userPoolId;
        private final java.lang.Object customDomainConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domain = this.jsiiGet("domain", java.lang.String.class);
            this.userPoolId = this.jsiiGet("userPoolId", java.lang.String.class);
            this.customDomainConfig = this.jsiiGet("customDomainConfig", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String domain, final java.lang.String userPoolId, final java.lang.Object customDomainConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domain = java.util.Objects.requireNonNull(domain, "domain is required");
            this.userPoolId = java.util.Objects.requireNonNull(userPoolId, "userPoolId is required");
            this.customDomainConfig = customDomainConfig;
        }

        @Override
        public java.lang.String getDomain() {
            return this.domain;
        }

        @Override
        public java.lang.String getUserPoolId() {
            return this.userPoolId;
        }

        @Override
        public java.lang.Object getCustomDomainConfig() {
            return this.customDomainConfig;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domain", om.valueToTree(this.getDomain()));
            data.set("userPoolId", om.valueToTree(this.getUserPoolId()));
            if (this.getCustomDomainConfig() != null) {
                data.set("customDomainConfig", om.valueToTree(this.getCustomDomainConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.CfnUserPoolDomainProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUserPoolDomainProps.Jsii$Proxy that = (CfnUserPoolDomainProps.Jsii$Proxy) o;

            if (!domain.equals(that.domain)) return false;
            if (!userPoolId.equals(that.userPoolId)) return false;
            return this.customDomainConfig != null ? this.customDomainConfig.equals(that.customDomainConfig) : that.customDomainConfig == null;
        }

        @Override
        public int hashCode() {
            int result = this.domain.hashCode();
            result = 31 * result + (this.userPoolId.hashCode());
            result = 31 * result + (this.customDomainConfig != null ? this.customDomainConfig.hashCode() : 0);
            return result;
        }
    }
}

==> cognito-1.93.0-sources.jar: software/amazon/awscdk/services/cognito/CfnUserPoolDomainProps.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Properties for defining a `AWS::Cognito::UserPoolDomain`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.464Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.CfnUserPoolDomainProps")
@software.amazon.jsii.Jsii.Proxy(CfnUserPoolDomainProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUserPoolDomainProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Cognito::UserPoolDomain.Domain`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDomain();

    /**
     * `AWS::Cognito::UserPoolDomain.UserPoolId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserPoolId();

    /**
     * `AWS::Cognito::UserPoolDomain.CustomDomainConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCustomDomainConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnUserPoolDomainProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUserPoolDomainProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUserPoolDomainProps> {
        private java.lang.String domain;
        private java.lang.String userPoolId;
        private java.lang.Object customDomainConfig;

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getDomain}
         * @param domain `AWS::Cognito::UserPoolDomain.Domain`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domain(java.lang.String domain) {
            this.domain = domain;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getUserPoolId}
         * @param userPoolId `AWS::Cognito::UserPoolDomain.UserPoolId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userPoolId(java.lang.String userPoolId) {
            this.userPoolId = userPoolId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getCustomDomainConfig}
         * @param customDomainConfig `AWS::Cognito::UserPoolDomain.CustomDomainConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customDomainConfig(software.amazon.awscdk.core.IResolvable customDomainConfig) {
            this.customDomainConfig = customDomainConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolDomainProps#getCustomDomainConfig}
         * @param customDomainConfig `AWS::Cognito::UserPoolDomain.CustomDomainConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customDomainConfig(software.amazon.awscdk.services.cognito.CfnUserPoolDomain.CustomDomainConfigTypeProperty customDomainConfig) {
            this.customDomainConfig = customDomainConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUserPoolDomainProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUserPoolDomainProps build() {
            return new Jsii$Proxy(domain, userPoolId, customDomainConfig);
        }
    }

    /**
     * An implementation for {@link CfnUserPoolDomainProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUserPoolDomainProps {
        private final java.lang.String domain;
        private final java.lang.String userPoolId;
        private final java.lang.Object customDomainConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domain = software.amazon.jsii.Kernel.get(this, "domain", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.userPoolId = software.amazon.jsii.Kernel.get(this, "userPoolId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.customDomainConfig = software.amazon.jsii.Kernel.get(this, "customDomainConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String domain, final java.lang.String userPoolId, final java.lang.Object customDomainConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domain = java.util.Objects.requireNonNull(domain, "domain is required");
            this.userPoolId = java.util.Objects.requireNonNull(userPoolId, "userPoolId is required");
            this.customDomainConfig = customDomainConfig;
        }

        @Override
        public final java.lang.String getDomain() {
            return this.domain;
        }

        @Override
        public final java.lang.String getUserPoolId() {
            return this.userPoolId;
        }

        @Override
        public final java.lang.Object getCustomDomainConfig() {
            return this.customDomainConfig;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domain", om.valueToTree(this.getDomain()));
            data.set("userPoolId", om.valueToTree(this.getUserPoolId()));
            if (this.getCustomDomainConfig() != null) {
                data.set("customDomainConfig", om.valueToTree(this.getCustomDomainConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.CfnUserPoolDomainProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUserPoolDomainProps.Jsii$Proxy that = (CfnUserPoolDomainProps.Jsii$Proxy) o;

            if (!domain.equals(that.domain)) return false;
            if (!userPoolId.equals(that.userPoolId)) return false;
            return this.customDomainConfig != null ? this.customDomainConfig.equals(that.customDomainConfig) : that.customDomainConfig == null;
        }

        @Override
        public final int hashCode() {
            int result = this.domain.hashCode();
            result = 31 * result + (this.userPoolId.hashCode());
            result = 31 * result + (this.customDomainConfig != null ? this.customDomainConfig.hashCode() : 0);
            return result;
        }
    }
}
